@@ -143,8 +143,16 @@ sub __module_version {
     confess "Bug - Module $module is not optional";
 }
 
+
+my %core = map { $_ => 1 } qw{ Time::HiRes };
+
 sub optionals {
-    return ( map { $_->modules() } @optionals );
+    # As of Test::Builder 1.302190 (March 2 2022) Time::HiRes is needed
+    # by Test::Builder, which is used by Test::More. It's a core module,
+    # so it OUGHT to be available, though there are known downstream
+    # packagers who strip core modules. Sigh. This is the reason I'm
+    # stripping it here rather than removing it completely.
+    return ( grep { ! $core{$_} } map { $_->modules() } @optionals );
 }
 
 sub recommend {
@@ -222,7 +230,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2010-2021 by Thomas R. Wyant, III
+Copyright (C) 2010-2022 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
